# -*- coding: utf-8 -*-
from __future__ import absolute_import
from __future__ import division
from __future__ import print_function
from __future__ import unicode_literals


def merge(reports):
    """Merge multiple report instances into one."""
    raise NotImplementedError
